## PAVÉS 0.2.x
- [ ] Implement and demonstrate CRF-based text extraction and
      segmentation
  - [ ] Find the friendliest and least dependency-encumbered Python
        CRF package
- [ ] Implement pypdfium2-based visualization
